From c1c77db7c3a3fc38c127509472c72bac68825634 Mon Sep 17 00:00:00 2001
From: Benjamin Drung <benjamin.drung@cloud.ionos.com>
Date: Wed, 11 Nov 2020 10:30:47 +0100
Subject: Fix spelling errors

lintian found some spelling errors.

Signed-off-by: Benjamin Drung <benjamin.drung@cloud.ionos.com>
---
 ibdiag/demo/sm-single-master.tcl    |  2 +-
 ibdiag/doc/ibdiagpath.pod           |  2 +-
 ibdiag/doc/ibdiagui.pod             |  2 +-
 ibdiag/src/ibdebug.tcl              |  8 ++++----
 ibdiag/src/ibdebug_if.tcl           |  6 +++---
 ibdiag/src/ibdiagui.tcl             |  4 ++--
 ibdm/doc/ibdm-topo-file.pod         |  2 +-
 ibdm/doc/ibdmsh.pod                 | 10 +++++-----
 ibdm/ibdm/CredLoops.cpp             |  4 ++--
 ibdm/ibdm/Fabric.cpp                | 16 ++++++++--------
 ibdm/ibdm/Fabric.h                  |  8 ++++----
 ibdm/ibdm/SubnMgt.cpp               |  2 +-
 ibdm/ibdm/TopoMatch.cpp             |  2 +-
 ibdm/ibdm/ibdm.i                    | 10 +++++-----
 ibdm/src/ibsysapi.cpp               | 10 +++++-----
 ibdm/src/ibsysapi.h                 |  4 ++--
 ibis/doc/ibis.pod                   |  4 ++--
 ibis/tests/ibvs_test.tcl            |  2 +-
 ibmgtsim/README                     |  2 +-
 ibmgtsim/tests/OsmTest.check.tcl    |  2 +-
 ibmgtsim/tests/README               |  2 +-
 ibmgtsim/tests/ibdiag-mcast.sim.tcl |  6 +++---
 ibmgtsim/tests/ibdiag-ucast.sim.tcl |  6 +++---
 ibmgtsim/tests/pkey.check.tcl       |  2 +-
 ibmgtsim/utils/RunSimTest           |  2 +-
 25 files changed, 60 insertions(+), 60 deletions(-)

diff --git a/ibdiag/demo/sm-single-master.tcl b/ibdiag/demo/sm-single-master.tcl
index 3dd5c65..dfd0fa4 100644
--- a/ibdiag/demo/sm-single-master.tcl
+++ b/ibdiag/demo/sm-single-master.tcl
@@ -130,7 +130,7 @@ proc checker {simDir osmPath osmPortGuid} {
 	puts "      -E- Found more then one master SM in the discover fabric\n"
 	puts " press Enter when done"
 	gets stdin
-	puts "   h. Make one of teh SMs sweep: kill -HUP %2."
+	puts "   h. Make one of the SMs sweep: kill -HUP %2."
    puts "      Now one of the SMs gets to standby mode"
 	puts "   i. Run ibdiagnet again to see the info about the SMs in /var/cache/ibutils/ibdiagnet.sm"
 	puts " "
diff --git a/ibdiag/doc/ibdiagpath.pod b/ibdiag/doc/ibdiagpath.pod
index 7f4a3f7..afc6317 100644
--- a/ibdiag/doc/ibdiagpath.pod
+++ b/ibdiag/doc/ibdiagpath.pod
@@ -16,7 +16,7 @@ ibdiagpath traces a path between two end-points and provides information
 regarding the nodes and ports traversed along the path. It utilizes device
 specific health queries for the different devices along the traversed path.
 The way ibdiagpath operates depends on the addressing mode used on the command
-line. If directed route adressing is used, the local node is the source node
+line. If directed route addressing is used, the local node is the source node
 and the route to the destination port is known apriori.
 On the other hand, if LID route (or by-name) addressing is imployed,
 then the source and destination ports of a route are specified by their LIDs
diff --git a/ibdiag/doc/ibdiagui.pod b/ibdiag/doc/ibdiagui.pod
index 6c21394..da0c01c 100644
--- a/ibdiag/doc/ibdiagui.pod
+++ b/ibdiag/doc/ibdiagui.pod
@@ -21,7 +21,7 @@ Its main features:
 
 =item  2. Hyperlink the ibdiagnet log to the graph objects
 
-=item  3. Show each object properties and object type specific actions on a properties pannel.
+=item  3. Show each object properties and object type specific actions on a properties panel.
 
 =back
 
diff --git a/ibdiag/src/ibdebug.tcl b/ibdiag/src/ibdebug.tcl
index 1527f9e..1e5d8ff 100644
--- a/ibdiag/src/ibdebug.tcl
+++ b/ibdiag/src/ibdebug.tcl
@@ -5347,7 +5347,7 @@ proc writeCSVGeneralInfoFile {} {
 					$curr_hdr_key == "sw_minor" ||
 					$curr_hdr_key == "sw_major" ||
 					$curr_hdr_key == "fw_ini_ver"} {
-					#depcrated keys
+					# deprecated keys
 					continue
 				}
 				lappend header_line $curr_hdr_key
@@ -5365,7 +5365,7 @@ proc writeCSVGeneralInfoFile {} {
 				$curr_hdr_key == "sw_minor" ||
 				$curr_hdr_key == "sw_major" ||
 				$curr_hdr_key == "fw_ini_ver"} {
-				#depcrated keys
+				# deprecated keys
 				continue
 			}
 			lappend node_line [lindex $GENERAL_INFO($curr_node_guid.general_info_list) $i]
@@ -5439,7 +5439,7 @@ proc writePMFile {} {
 ##############################
 #  NAME         writeTopologyFileAndIBNLs
 #  SYNOPSIS     writeTopologyFileAndIBNLs
-#  FUNCTION     Write out teh topoly fiel if requested
+#  FUNCTION     Write out the topology file if requested
 #  INPUTS       NULL
 #  OUTPUT       NULL
 proc writeTopologyFileAndIBNLs {} {
@@ -5452,7 +5452,7 @@ proc writeTopologyFileAndIBNLs {} {
 	    file mkdir $ibnlDir
 	}
 
-	# we might be teh only reason to get a topology ...
+	# we might be the only reason to get a topology ...
 	if {![info exists G(IBfabric:merged)] } {
 	    set f [new_IBFabric]
 	    if {[IBFabric_parseSubnetLinks $f  $G(outfiles,.lst)]} {
diff --git a/ibdiag/src/ibdebug_if.tcl b/ibdiag/src/ibdebug_if.tcl
index df626f1..0e4ea16 100644
--- a/ibdiag/src/ibdebug_if.tcl
+++ b/ibdiag/src/ibdebug_if.tcl
@@ -2678,7 +2678,7 @@ proc showHelpPage { args } {
             regarding the nodes and ports traversed along the path. It utilizes device
             specific health queries for the different devices along the traversed path.
             The way ibdiagpath operates depends on the addressing mode used on the command
-            line. If directed route adressing is used, the local node is the source node
+            line. If directed route addressing is used, the local node is the source node
             and the route to the destination port is known apriori.
             On the other hand, if LID route (or by-name) addressing is imployed,
          then the source and destination ports of a route are specified by their LIDs
@@ -2799,10 +2799,10 @@ proc showHelpPage { args } {
 	"DESCRIPTION
             ibdiagui is a GUI wrapper for ibdiagnet.
             Its main features:
-            1. Display a graph of teh discovered fabric (with optional names annotattion)
+            1. Display a graph of the discovered fabric (with optional names annotattion)
             2. Hyperlink the ibdiagnet log to the graph objects
             3. Show each object properties and object type specific actions
-            on a properties pannel."
+            on a properties panel."
 
     # OPTIONS
     # -<field-i> <val-i>: specific attribute field and value. Automatically sets the component mask bit.
diff --git a/ibdiag/src/ibdiagui.tcl b/ibdiag/src/ibdiagui.tcl
index ef9c23e..3b0c819 100644
--- a/ibdiag/src/ibdiagui.tcl
+++ b/ibdiag/src/ibdiagui.tcl
@@ -753,7 +753,7 @@ proc drawFabric {fabric c} {
    # fit $c
 }
 
-#assume there is a name:* tag in teh list return the name
+#assume there is a name:* tag in the list return the name
 proc getNameTag {tags} {
    set idx [lsearch -glob $tags name:*]
    if {$idx < 0} {
@@ -1897,7 +1897,7 @@ proc LogObjSelect {log type w x y} {
    }
 }
 
-# initialize the props guid such that we have a pannel
+# initialize the props guid such that we have a panel
 # for each object type
 proc initPropsGui {p} {
    global PROPS O
diff --git a/ibdm/doc/ibdm-topo-file.pod b/ibdm/doc/ibdm-topo-file.pod
index 7deba46..cba8975 100644
--- a/ibdm/doc/ibdm-topo-file.pod
+++ b/ibdm/doc/ibdm-topo-file.pod
@@ -66,7 +66,7 @@ A name of the remote system port. We use the numbers as printed on the front pan
 
 =head1 EXAMPLE
 
-The following is a topology file for a simple cluster with one 24 port switch and two HCAs. The firts HCA named H-1 and connect to the fabric with its two ports. The second HCA named H-2. The switch is of type MTS2400 and is named S-1
+The following is a topology file for a simple cluster with one 24 port switch and two HCAs. The first HCA named H-1 and connect to the fabric with its two ports. The second HCA named H-2. The switch is of type MTS2400 and is named S-1
 
 MTS2400 S-1
    P1 -> MT23108 H-1 P1
diff --git a/ibdm/doc/ibdmsh.pod b/ibdm/doc/ibdmsh.pod
index 1386d5e..38a5134 100644
--- a/ibdm/doc/ibdmsh.pod
+++ b/ibdm/doc/ibdmsh.pod
@@ -53,7 +53,7 @@ Log level: set to FABU_LOG* values
 
 =head1 IBDM Objects
 
-This section decribes the various object types exposed by IBDM.
+This section describes the various object types exposed by IBDM.
 
 
 IBDM exposes some of its internal objects. The objects identifiers returned by the various function calls are formatted according to the following rules:
@@ -150,7 +150,7 @@ Modify the guid of the port
 
 =item [ Member : returns new_string  ] getName
 
-Get the port name: A device port connected to system port (front pannel) returns the front pannel port name.
+Get the port name: A device port connected to system port (front panel) returns the front panel port name.
 
 =item [ Member : returns void  ] connect p_otherPort ?width? ?speed?
 
@@ -268,13 +268,13 @@ Dump out the min hop table of the node
 
 =head2 class IBSysPort
 
-The IBSysPort class represents an IB plug on the system front or back pannels
+The IBSysPort class represents an IB plug on the system front or back panels
 
 =over
 
 =item [ Member data: returns string * ] -name
 
-The front pannel name (silk) of the port
+The front panel name (silk) of the port
 
 =item [ Member data: returns IBSysPort * ] -p_remoteSysPort
 
@@ -414,7 +414,7 @@ Create a new generic system - basically an empty container for nodes...
 
 =item [ Member : returns IBSystem * ] makeSystem name type
 
-Create a new system - the type must have a registed factory.
+Create a new system - the type must have a registered factory.
 
 =item [ Member : returns IBSystem * ] getSystem name
 
diff --git a/ibdm/ibdm/CredLoops.cpp b/ibdm/ibdm/CredLoops.cpp
index 1817260..732361b 100644
--- a/ibdm/ibdm/CredLoops.cpp
+++ b/ibdm/ibdm/CredLoops.cpp
@@ -407,14 +407,14 @@ CrdLoopConnectMcastDepend(IBFabric* p_fabric)
                     IBPort *p_outPort = p_node->getPort(outPortNum);
                     if (! p_outPort) {
                         cout << "-E- Switch:" << p_node->name << " port:" << outPortNum
-                                << " is included in some MFT but is not connnected" << endl;
+                                << " is included in some MFT but is not connected" << endl;
                         nErrs++;
                         continue;
                     }
                     IBPort *p_inPort = p_node->getPort(inPortNum);
                     if (! p_inPort) {
                         cout << "-E- Switch:" << p_node->name << " port:" << inPortNum
-                                << " is included in some MFT but is not connnected" << endl;
+                                << " is included in some MFT but is not connected" << endl;
                         nErrs++;
                         continue;
                     }
diff --git a/ibdm/ibdm/Fabric.h b/ibdm/ibdm/Fabric.h
index d4e4e7d..386ba61 100644
--- a/ibdm/ibdm/Fabric.h
+++ b/ibdm/ibdm/Fabric.h
@@ -426,11 +426,11 @@ class IBNode {
 ///////////////////////////////////////////////////////////////////////////////
 //
 // System Port Class
-// The System Port is a front pannel entity.
+// The System Port is a front panel entity.
 //
 class IBSysPort {
 public:
-    string          name;               // The front pannel name of the port
+    string          name;               // The front panel name of the port
     class IBSysPort *p_remoteSysPort;   // If connected the other side sys port
     class IBSystem  *p_system;          // System it benongs to
     class IBPort    *p_nodePort;        // The node port it connects to.
@@ -564,10 +564,10 @@ public:
     // return the list of node pointers matching the required type
     list_pnode *getNodesByType(IBNodeType type);
 
-    // crate a new generic system - basically an empty contaner for nodes...
+    // create a new generic system - basically an empty contaner for nodes...
     IBSystem *makeGenericSystem(string name);
 
-    // crate a new system - the type must have a pre-red SysDef
+    // create a new system - the type must have a pre-red SysDef
     IBSystem *makeSystem(string name, string type, string cfg = "");
 
     // get a system by name
diff --git a/ibdm/ibdm/SubnMgt.cpp b/ibdm/ibdm/SubnMgt.cpp
index 9de792c..106cfe5 100644
--- a/ibdm/ibdm/SubnMgt.cpp
+++ b/ibdm/ibdm/SubnMgt.cpp
@@ -886,7 +886,7 @@ SubnMgtVerifyAllCaToCaRoutes(IBFabric *p_fabric)
     // track the number of dlids actually routed through each switch port.
     // to avoid memory scalability we do the path scanning with dest port
     // in the external loop. So we only need to look on the aggregated
-    // vectore per port at the end of all sources and sum up to teh final results
+    // vectore per port at the end of all sources and sum up to the final results
     map_pnode_vec_int switchDLidsPerOutPort;
 
     cout << "-I- Verifying all CA to CA paths ... " << endl;
diff --git a/ibdm/ibdm/TopoMatch.cpp b/ibdm/ibdm/TopoMatch.cpp
index 434bb3c..fb82f83 100644
--- a/ibdm/ibdm/TopoMatch.cpp
+++ b/ibdm/ibdm/TopoMatch.cpp
@@ -1993,7 +1993,7 @@ TopoMatchSwitches(IBFabric *p_sFabric,
         }
     }
     if (numMatchedSws) {
-        s << "-I- Successfuly matched " << numMatchedSws
+        s << "-I- Successfully matched " << numMatchedSws
                 << " more switches" << endl;
     }
     return(numMatchedSws);
diff --git a/ibdm/ibdm/ibdm.i b/ibdm/ibdm/ibdm.i
index e21b74a..822ff59 100644
--- a/ibdm/ibdm/ibdm.i
+++ b/ibdm/ibdm/ibdm.i
@@ -899,7 +899,7 @@ int ibdmUseCoutLog();
 /* obtain log messages from internal log and clear it */
 
 %section "IBDM Objects",pre
-/* This section decribes the various object types exposed by IBDM. */
+/* This section describes the various object types exposed by IBDM. */
 %text %{
 
   IBDM exposes some of its internal objects. The objects
@@ -1041,11 +1041,11 @@ class IBNode {
 
 //
 // System Port Class
-// The System Port is a front pannel entity.
+// The System Port is a front panel entity.
 //
 class IBSysPort {
  public:
-  string			   name;              // The front pannel name of the port
+  string			   name;              // The front panel name of the port
   IBSysPort	*p_remoteSysPort;  // If connected the other side sys port
   IBSystem	*p_system;         // System it benongs to
   IBPort	   *p_nodePort;       // The node port it connects to.
@@ -1135,10 +1135,10 @@ class IBFabric {
   // return the list of node pointers matching the required type
 
   IBSystem *makeGenericSystem (string name);
-  // crate a new generic system - basically an empty contaner for nodes...
+  // create a new generic system - basically an empty contaner for nodes...
 
   IBSystem *makeSystem (string name, string type);
-  // crate a new system - the type must have a registed factory.
+  // create a new system - the type must have a registered factory.
 
   IBSystem *getSystem(string name);
   // Get system by name
diff --git a/ibdm/src/ibsysapi.h b/ibdm/src/ibsysapi.h
index 587c331..d7e48a1 100644
--- a/ibdm/src/ibsysapi.h
+++ b/ibdm/src/ibsysapi.h
@@ -63,11 +63,11 @@ int ibSysGetDrPathsToNode(char *fromNode, char *toNode,
 /* query all node names in the system */
 int ibSysGetNodes(int *numNodes, const char **nodeNames);
 
-/* query name of front pannel port of a node port */
+/* query name of front panel port of a node port */
 int ibSysGetNodePortSysPort(char *nodeName, int portNum,
         const char **sysPortName);
 
-/* query node name and port given front pannel port name */
+/* query node name and port given front panel port name */
 int ibSysGetNodePortOnSysPort(char *sysPort,
         const char**nodeName, int *portNum);
 
diff --git a/ibis/doc/ibis.pod b/ibis/doc/ibis.pod
index 7102ca1..5659918 100644
--- a/ibis/doc/ibis.pod
+++ b/ibis/doc/ibis.pod
@@ -144,7 +144,7 @@ Obtain the maximal number of parallel queries that can be sent
 
 =item [ returns int  ] pmGetPortCounters lid port_select
 
-Send a "PortCounters" query to teh given LID and port
+Send a "PortCounters" query to the given LID and port
 
 =item [ returns int  ] pmGetPortCountersMulti num lid_list port_select_list
 
@@ -1095,7 +1095,7 @@ Methods:
 =head2 INFORM INFO RECORD
 
 
-The inform Info is built with heirarchy of objects. So several classes are defined.
+The inform Info is built with hierarchy of objects. So several classes are defined.
 
 ----
 
diff --git a/ibis/tests/ibvs_test.tcl b/ibis/tests/ibvs_test.tcl
index 7a4d68c..442898a 100755
--- a/ibis/tests/ibvs_test.tcl
+++ b/ibis/tests/ibvs_test.tcl
@@ -58,7 +58,7 @@ vsI2cWriteMulti
 
 We perform the following flow for verification:
 read1 - read some addresses from the EEPROM assuming fixed addresses
-read2 - repeat from teh other devices
+read2 - repeat from the other devices
 read3 - do multi read and verify we got same result
 read4 - try reading same multi read but this time with some garbadge lid too.
         verify we still get what expect.
diff --git a/ibmgtsim/README b/ibmgtsim/README
index 1e13ab7..bd118d6 100644
--- a/ibmgtsim/README
+++ b/ibmgtsim/README
@@ -46,7 +46,7 @@ HOWTO BUILD
    NOTE: the pointer to the osm install path can be to any osm (not just the
    one compiled with the simulator interface vendor layer. e.g. /usr)
 
-   --enable-maintainer-mode - will enable updating fo teh TCL API (by running
+   --enable-maintainer-mode - will enable updating of the TCL API (by running
      swig) after modifications to any of the .i files. It also enables update
     of the ibnl_parser.cc, ibnl_parser.h after changes to ibnl_parser.yy and
     similarly updates to ibnl_scanner.cc after modification of ibnl_scanner.ll
diff --git a/ibmgtsim/tests/OsmTest.check.tcl b/ibmgtsim/tests/OsmTest.check.tcl
index 287d8e4..ea557ff 100644
--- a/ibmgtsim/tests/OsmTest.check.tcl
+++ b/ibmgtsim/tests/OsmTest.check.tcl
@@ -71,6 +71,6 @@ proc checker {simDir osmPath osmPortGuid} {
       return 1
    }
 
-   puts "-I- osmtest completed successfuly"
+   puts "-I- osmtest completed successfully"
    return 0
 }
diff --git a/ibmgtsim/tests/README b/ibmgtsim/tests/README
index bfa7484..9d21f96 100644
--- a/ibmgtsim/tests/README
+++ b/ibmgtsim/tests/README
@@ -20,7 +20,7 @@ ibdiag-drops.sim.tcl - set some bad links
 ibdiag-dup-node-guid.sim.tcl - duplicate node guid
 ibdiag-dup-port-guid.sim.tcl - duplicate port guid
 ibdiag-lid.sim.tcl - post the SM run duplicate or zero some lids
-ibdiag-mcast.sim.tcl - post SM create 3 MGRPs join some ports, then disconenct some MFT routing
+ibdiag-mcast.sim.tcl - post SM create 3 MGRPs join some ports, then disconnect some MFT routing
 ibdiag-ucast.sim.tcl - post SM delete some LFT entries
 
 
diff --git a/ibmgtsim/tests/ibdiag-mcast.sim.tcl b/ibmgtsim/tests/ibdiag-mcast.sim.tcl
index 6456749..8b2ec6c 100644
--- a/ibmgtsim/tests/ibdiag-mcast.sim.tcl
+++ b/ibmgtsim/tests/ibdiag-mcast.sim.tcl
@@ -179,7 +179,7 @@ proc postSmSettings {fabric} {
       puts "-E- $e"
       puts $errorInfo
    }
-   set nDisconencted 0
+   set nDisconnected 0
 
    after 1000
 if {[catch {
@@ -187,14 +187,14 @@ if {[catch {
    for {set i 0} {$i < 3} {incr i} {
       # delete one entry
       if {![removeMCastRouteEntry $fabric]} {
-         incr nDisconencted
+         incr nDisconnected
       }
    }
 } e]} {
 puts $e
 puts $errorInfo
 }
-   return "-I- Joined $nPorts Disconnected $nDisconencted"
+   return "-I- Joined $nPorts Disconnected $nDisconnected"
 }
 
 # make sure ibdiagnet reported the bad links
diff --git a/ibmgtsim/tests/ibdiag-ucast.sim.tcl b/ibmgtsim/tests/ibdiag-ucast.sim.tcl
index f072d39..5c52ec6 100644
--- a/ibmgtsim/tests/ibdiag-ucast.sim.tcl
+++ b/ibmgtsim/tests/ibdiag-ucast.sim.tcl
@@ -93,15 +93,15 @@ proc removeUCastRouteEntry {fabric} {
 # setup post SM run changes:
 proc postSmSettings {fabric} {
    global errorInfo
-   set nDisconencted 0
+   set nDisconnected 0
    # now go and delete some switch MC entries...
    for {set i 0} {$i < 3} {incr i} {
       # delete one entry
       if {![removeUCastRouteEntry $fabric]} {
-         incr nDisconencted
+         incr nDisconnected
       }
    }
-   return "-I- Disconnected $nDisconencted LFT Entries"
+   return "-I- Disconnected $nDisconnected LFT Entries"
 }
 
 # make sure ibdiagnet reported the bad links
diff --git a/ibmgtsim/tests/pkey.check.tcl b/ibmgtsim/tests/pkey.check.tcl
index 2a262d2..687aa71 100644
--- a/ibmgtsim/tests/pkey.check.tcl
+++ b/ibmgtsim/tests/pkey.check.tcl
@@ -363,7 +363,7 @@ proc checker {simDir osmPath osmPortGuid} {
    puts "SIM: $res"
 
    if {$res == 0} {
-      puts "-I- Pkey check flow completed successfuly"
+      puts "-I- Pkey check flow completed successfully"
    } else {
       puts "-E- Pkey check flow failed"
    }
diff --git a/ibmgtsim/utils/RunSimTest b/ibmgtsim/utils/RunSimTest
index a79a82b..561f344 100755
--- a/ibmgtsim/utils/RunSimTest
+++ b/ibmgtsim/utils/RunSimTest
@@ -342,7 +342,7 @@ proc checker {simDir osmPath osmPortGuid} {
          puts $e
          set exitCode 1
       } else {
-         puts "-I- ibdmchk completed successfuly"
+         puts "-I- ibdmchk completed successfully"
          set exitCode 0
       }
    }
diff --git a/ibdm/ibdm/Fabric.cpp b/ibdm/ibdm/Fabric.cpp
index 66f0090..0939b78 100644
--- a/ibdm/ibdm/Fabric.cpp
+++ b/ibdm/ibdm/Fabric.cpp
@@ -197,7 +197,7 @@ int
 IBPort::disconnect(int duringSysPortDisconnect)
 {
     if (!p_remotePort) {
-        cout << "-W- Trying to disconenct non connected port." << endl;
+        cout << "-W- Trying to disconnect non-connected port." << endl;
         return(1);
     }
 
@@ -214,7 +214,7 @@ IBPort::disconnect(int duringSysPortDisconnect)
         cout << "-I- Disconnected port:" << getName()
             << " from:" << p_remPort->getName() << endl;
 
     // might need to treat the sys port too - but mark it duringPortDisconenct
     if (p_sysPort && ! duringSysPortDisconnect)
         return(p_sysPort->disconnect(1));
 
@@ -649,7 +649,7 @@ int
 IBSysPort::disconnect(int duringPortDisconnect)
 {
     if (!p_remoteSysPort) {
-        cout << "-W- Trying to disconenct non connected system port." << endl;
+        cout << "-W- Trying to disconnect non-connected system port." << endl;
         return(1);
     }
 
@@ -667,7 +667,7 @@ IBSysPort::disconnect(int duringPortDisconnect)
         cout << "-I- Disconnected system port:" << name
             << " from:" << p_remSysPort->name << endl;
 
     // might need to treat the port too - but mark it duringPortDisconenct
     if (p_nodePort && ! duringPortDisconnect) return(p_nodePort->disconnect(1));
     return(0);
 }
@@ -1106,7 +1106,7 @@ cfgStrToModifiers(string cfg, map_str_str &mods)
     return(0);
 }
 
-// crate a new generic system - basically an empty contaner for nodes...
+// create a new generic system - basically an empty contaner for nodes...
 IBSystem *
 IBFabric::makeGenericSystem(string name)
 {
@@ -1122,7 +1122,7 @@ IBFabric::makeGenericSystem(string name)
     return p_sys;
 }
 
-// crate a new system - the type must have a predefined sysdef
+// create a new system - the type must have a predefined sysdef
 IBSystem *
 IBFabric::makeSystem(string name, string type, string cfg)
 {
@@ -2277,7 +2277,7 @@ IBFabric::dumpTopology(const char *fileName, const char * ibnlDir)
         cout << "-E- failed to open:" << fileName << " for writing." << endl;
         return 1;
     }
-    sout << "# This topology file was automaticlly generated by IBDM" << endl;
+    sout << "# This topology file was automatically generated by IBDM" << endl;
 
     // we start with all systems at top level:
     for (map_str_psys::iterator sI = SystemByName.begin();
@@ -2335,7 +2335,7 @@ IBFabric::dumpNameMap(const char *fileName)
         cout << "-E- failed to open:" << fileName << " for writing." << endl;
         return 1;
     }
-    sout << "# This name map file was automaticlly generated by IBDM" << endl;
+    sout << "# This name map file was automatically generated by IBDM" << endl;
     sout << "# NodeGUID PortLID NAME/SysImageGUID" << endl;
 
     // Go over all nodes of the fabric
@@ -214,7 +214,7 @@ IBPort::disconnect(int duringSysPortDisconnect)
             << " from:" << p_remPort->getName() << endl;
 
-    // might need to treat the sys port too - but mark it duringPortDisconenct
+    // might need to treat the sys port too - but mark it duringPortDisconnect
     if (p_sysPort && ! duringSysPortDisconnect)
         return(p_sysPort->disconnect(1));
@@ -667,7 +667,7 @@ IBSysPort::disconnect(int duringPortDisconnect)
             << " from:" << p_remSysPort->name << endl;
 
-    // might need to treat the port too - but mark it duringPortDisconenct
+    // might need to treat the port too - but mark it duringPortDisconnect
     if (p_nodePort && ! duringPortDisconnect) return(p_nodePort->disconnect(1));
     return(0);
diff --git a/ibdm/src/ibsysapi.cpp b/ibdm/src/ibsysapi.cpp
index d8ed319..6dc6a0f 100644
--- a/ibdm/src/ibsysapi.cpp
+++ b/ibdm/src/ibsysapi.cpp
@@ -340,7 +340,7 @@ ibSysGetNodePortSysPort(char *nodeName, int portNum,
 
     if (!port->p_sysPort) {
         if (ibSysVerbose & IBSYS_ERROR) {
-            printf("Error: no front pannel port at node:%s port:%d\n",
+            printf("Error: no front panel port at node:%s port:%d\n",
                     nodeName, portNum);
         }
         *sysPortName = NULL;
@@ -356,7 +356,7 @@ ibSysGetNodePortSysPort(char *nodeName, int portNum,
 }
 
 
 /* query node name and port given front pannel port name */
 int
 ibSysGetNodePortOnSysPort(char *sysPortName,
         const char**nodeName, int *portNum)
@@ -370,7 +370,7 @@ ibSysGetNodePortOnSysPort(char *sysPortName,
 
     if (!sysPortName) {
         if (ibSysVerbose & IBSYS_ERROR) {
-            printf("Error: No front pannel port name provided\n");
+            printf("Error: No front panel port name provided\n");
         }
         return(1);
     }
@@ -400,7 +400,7 @@ ibSysGetNodePortOnSysPort(char *sysPortName,
     IBSysPort *sysPort = system->getSysPort(sysPortName);
     if (!sysPort) {
         if (ibSysVerbose & IBSYS_ERROR) {
-            printf("Error: failed to find system front pannel port:%s\n",
+            printf("Error: failed to find system front panel port:%s\n",
                     sysPortName);
         }
         return(1);
@@ -408,7 +408,7 @@ ibSysGetNodePortOnSysPort(char *sysPortName,
 
     if (!sysPort->p_nodePort) {
         if (ibSysVerbose & IBSYS_ERROR) {
-            printf("Error: failed to find system front pannel port:%s node port?\n",
+            printf("Error: failed to find system front panel port:%s node port?\n",
                     sysPortName);
         }
         return(1);
@@ -356,7 +356,7 @@ ibSysGetNodePortSysPort(char *nodeName, int portNum,
 
 
-/* query node name and port given front pannel port name */
+/* query node name and port given front panel port name */
 int
 ibSysGetNodePortOnSysPort(char *sysPortName,
-- 
2.25.1

